---
title: '[릴리즈노트] 2024-11-25 파트너 정산 자동화 업데이트'
category: 업데이트
tags:
  - 파트너정산
  - 업데이트
searchTags:
  - 국세청 연동
  - 세금계산서
  - '파트너 다수 '
  - '대량 '
  - 세금계산서 발행
datetime: 2025-03-04T02:46:19.360Z
---

<Callout title="2024년 11월 25일 파트너 정산 자동화 업데이트 소식을 안내드립니다." />



<Callout content="안녕하세요 파트너 정산 자동화팀입니다.

24년 11월 25일, 서비스 업데이트 사항 안내드립니다.
이번 업데이트에서는 세금계산서 역발행 신규 기능을 제공합니다.

1. 파트너 다수에게 대량으로 세금계산서 발행 승인 요청을 보낼 수 있어 일일이 작업하는 노고를 줄여 드립니다.
2. 국세청 사이트에 방문하지 않고도 세금계산서 발행 및 수정 세금계산서 작성이 가능합니다." />

## **주요 업데이트 사항**

✔️ **국세청 연동**

- 콘솔 우측 최상단 \[세금계산서 연동관리]에서 공동인증서를 1회만 연동 완료하면, 손쉽게 역발행 세금계산서를 작성/관리 할 수 있습니다.



✔️**세금계산서 작성**

- 세금계산서를 작성 중 임시저장 할 수 있습니다.



- 국세청에서 제공하는 전자세금계산서 양식으로 편리하게 사용할 수 있습니다.



✔️ **세금계산서 일괄 등록**

- 포트원에서 제공하는 양식에 맞추어 csv 파일 작성 완료 후 콘솔에 업데이트 하면, 자동으로 데이터가 입력됩니다.



- 세금계산서의 역발행 승인 요청 / 발행 / 국세청 전송 상태를 간편하게 확인할 수 있습니다.



✔️ **파트너 국세청 연동 및 세금계산서 조회/승인/거부**

- 공급자는 이메일에서 최초 1회 공동인증서를 연동 완료 한 후, 세금계산서 조회/승인/거부할 수 있습니다.



✔️ **수정 세금계산서 작성**

- 세금계산서를 국세청에 전송한 이후에 수정이 필요한 경우,국세청 홈페이지 방문 없이 포트원 콘솔에서 수정 세금계산서 작성이 가능합니다.



#### **API 변경사항**

✔️ **파트너 관련 API**

파트너 다건 조회 요청 본문이 수정되었습니다.

- `PlatformPartnerFilterInput` 파트너 필터 입력 정보에 필드가 추가되었습니다.
  - `types` : PlatformPartnerTypeName 파트너 유형 필터가 추가되었습니다.
  - `taxationTypes` : PlatformPartnerTaxationType 파트너 과세 유형 필터가 추가되었습니다.
  - `memberCompanyConnectionStatuses` : PlatformPartnerMemberCompanyConnectionStatus 파트너 연동 사업자 연결 상태 필터가 추가되었습니다.

파트너 관련 API들의 응답 본문이 수정되었습니다.

- `PlatformPartnerTypeBusiness` 파트너 사업자 정보에 필드가 추가되었습니다.
  - `memberCompanyConnectionStatus` : PlatformPartnerMemberCompanyConnectionStatus 파트너 연동 사업자 연결 상태가 추가되었습니다.
  - `memberCompanyConnectionFailedReason?`: String 연동사업자 연결 실패 사유가 추가되었습니다.

✔️ **사업자 조회**

- 사업자 조회 API가 추가 되었습니다.



##### [\[파트너정산 릴리즈노트\] 2024-11-25업데이트 보러가기↗](https://developers.portone.io/release-notes/platform/2024-11-25)
